[![MIT License][license-shield]][license-url]
# SubtitleTranslator

SubtitleTranslator is a python subtitle translator as a command-line tool.

### Installation

```sh
$ pip install subtrans
```
### Usage

```sh
$ subtrans translate subtitle.srt --src en -dest fa
```

License
----

MIT

<!-- MARKDOWN LINKS & IMAGES -->
[license-shield]: https://img.shields.io/github/license/othneildrew/Best-README-Template.svg?style=for-the-badge
[license-url]: https://github.com/othneildrew/Best-README-Template/blob/master/LICENSE.txt